==> jc-1.4.0.tar.gz: jas/InvokeinterfaceInsn.h <==
// public class jas.InvokeinterfaceInsn

// class file dependencies
// @dep_class 4062a5c70c6293f0 jas_Insn
// @dep_class e548f6075b28ea58 jas_InvokeinterfaceInsn
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_Insn

#include "jas/Insn.h"

#ifndef _JC_jas_InvokeinterfaceInsn_H_
#define _JC_jas_InvokeinterfaceInsn_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_InvokeinterfaceInsn$sub_refs	_jc_jas_InvokeinterfaceInsn$sub_refs;
typedef struct _jc_jas_InvokeinterfaceInsn$sub_nonrefs	_jc_jas_InvokeinterfaceInsn$sub_nonrefs;
typedef struct _jc_jas_InvokeinterfaceInsn$refs	_jc_jas_InvokeinterfaceInsn$refs;
typedef struct _jc_jas_InvokeinterfaceInsn$nonrefs	_jc_jas_InvokeinterfaceInsn$nonrefs;
typedef struct _jc_jas_InvokeinterfaceInsn$object	_jc_jas_InvokeinterfaceInsn$object;

typedef const struct _jc_jas_InvokeinterfaceInsn$vmethods	_jc_jas_InvokeinterfaceInsn$vmethods;
typedef const struct _jc_jas_InvokeinterfaceInsn$vtable	_jc_jas_InvokeinterfaceInsn$vtable;
typedef const struct _jc_jas_InvokeinterfaceInsn$vtype	_jc_jas_InvokeinterfaceInsn$vtype;

// Constructors
extern void _jc_jas_InvokeinterfaceInsn$method$_init$ac87c5b24fe5e7ef(_jc_env *, struct _jc_jas_InvokeinterfaceInsn$object *, struct _jc_jas_CP$object *, jint);

// Virtual methods structure
struct _jc_jas_InvokeinterfaceInsn$vmethods {
};

// Vtable
struct _jc_jas_InvokeinterfaceInsn$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Insn$vmethods	jas_Insn;
	_jc_jas_InvokeinterfaceInsn$vmethods	jas_InvokeinterfaceInsn;
};

// Vtype
struct _jc_jas_InvokeinterfaceInsn$vtype {
	_jc_type			type;
	_jc_jas_InvokeinterfaceInsn$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_InvokeinterfaceInsn$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_InvokeinterfaceInsn$refs {
    _jc_jas_InvokeinterfaceInsn$sub_refs	jas_InvokeinterfaceInsn;
    _jc_jas_Insn$sub_refs	jas_Insn;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_InvokeinterfaceInsn$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_InvokeinterfaceInsn$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Insn$sub_nonrefs	jas_Insn;
    _jc_jas_InvokeinterfaceInsn$sub_nonrefs	jas_InvokeinterfaceInsn;
};

// Object instance structure
struct _jc_jas_InvokeinterfaceInsn$object {
	_jc_jas_InvokeinterfaceInsn$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_InvokeinterfaceInsn$vtype	*vtype;
	_jc_jas_InvokeinterfaceInsn$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_InvokeinterfaceInsn$vtype _jc_jas_InvokeinterfaceInsn$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_InvokeinterfaceInsn, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_InvokeinterfaceInsn$class_object;

#endif	/* _JC_jas_InvokeinterfaceInsn_H_ */

==> jc-1.4.6.tar.gz: jas/InvokeinterfaceInsn.h <==
// public class jas.InvokeinterfaceInsn

// class file dependencies
// @dep_class 4062a5c70c6293f0 jas_Insn
// @dep_class e548f6075b28ea58 jas_InvokeinterfaceInsn
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_Insn

#include "jas/Insn.h"

#ifndef _JC_jas_InvokeinterfaceInsn_H_
#define _JC_jas_InvokeinterfaceInsn_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_InvokeinterfaceInsn$sub_refs	_jc_jas_InvokeinterfaceInsn$sub_refs;
typedef struct _jc_jas_InvokeinterfaceInsn$sub_nonrefs	_jc_jas_InvokeinterfaceInsn$sub_nonrefs;
typedef struct _jc_jas_InvokeinterfaceInsn$refs	_jc_jas_InvokeinterfaceInsn$refs;
typedef struct _jc_jas_InvokeinterfaceInsn$nonrefs	_jc_jas_InvokeinterfaceInsn$nonrefs;
typedef struct _jc_jas_InvokeinterfaceInsn$object	_jc_jas_InvokeinterfaceInsn$object;

typedef const struct _jc_jas_InvokeinterfaceInsn$vmethods	_jc_jas_InvokeinterfaceInsn$vmethods;
typedef const struct _jc_jas_InvokeinterfaceInsn$vtable	_jc_jas_InvokeinterfaceInsn$vtable;
typedef const struct _jc_jas_InvokeinterfaceInsn$vtype	_jc_jas_InvokeinterfaceInsn$vtype;

// Constructors
extern void _jc_jas_InvokeinterfaceInsn$method$_init$ac87c5b24fe5e7ef(_jc_env *, struct _jc_jas_InvokeinterfaceInsn$object *, struct _jc_jas_CP$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jas_InvokeinterfaceInsn$vmethods {
};

// Vtable
struct _jc_jas_InvokeinterfaceInsn$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Insn$vmethods	jas_Insn;
	_jc_jas_InvokeinterfaceInsn$vmethods	jas_InvokeinterfaceInsn;
};

// Vtype
struct _jc_jas_InvokeinterfaceInsn$vtype {
	_jc_type			type;
	_jc_jas_InvokeinterfaceInsn$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_InvokeinterfaceInsn$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_InvokeinterfaceInsn$refs {
    _jc_jas_InvokeinterfaceInsn$sub_refs	jas_InvokeinterfaceInsn;
    _jc_jas_Insn$sub_refs	jas_Insn;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_InvokeinterfaceInsn$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_InvokeinterfaceInsn$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Insn$sub_nonrefs	jas_Insn;
    _jc_jas_InvokeinterfaceInsn$sub_nonrefs	jas_InvokeinterfaceInsn;
};

// Object instance structure
struct _jc_jas_InvokeinterfaceInsn$object {
	_jc_jas_InvokeinterfaceInsn$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_InvokeinterfaceInsn$vtype	*vtype;
	_jc_jas_InvokeinterfaceInsn$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_InvokeinterfaceInsn$vtype _jc_jas_InvokeinterfaceInsn$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_InvokeinterfaceInsn, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_InvokeinterfaceInsn$class_object;

#endif	/* _JC_jas_InvokeinterfaceInsn_H_ */
